#!/bin/sh

# Set Linux PATH Environment Variables
PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:~/bin
export PATH

# PubKey Name & Link
PubKeyName=YourPubKeyName
PubKeyLink=http://www.sample.com/

# Check If You Are Root
if [ $(id -u) != "0" ]; then
    clear
    echo -e "\033[33m Error: You must be root to run this script! \033[0m"
    exit 1
fi

# Disable BASH History For Session
unset HISTFILE
stty erase '^?'

# Preparation
function minimal_prepare() {
    echo -e "\033[32m >>> Prepare for Script ... \033[0m"
    if [ ! -d tmp ]; then
        mkdir -p tmp
    fi
    if [ ! -f /usr/bin/diff ]; then
        yum install -y diffutils
    fi
    if [ ! -f /usr/bin/wget ]; then
        yum install -y wget
    fi
}
# Clean Dotfiles
function configure_bashrc() {
    echo -e "\033[32m >>> Configuring: Bashrc ... \033[0m"
    # Remove Skel Dotfiles
    rm -rf /etc/skel/.??*
    # Update Home Dotfiles
    cp -f -a -R settings/skel/.??* ~
    # Update Skel Dotfiles
    cp -f -a -R settings/skel/.??* /etc/skel
    # Append Umask
    echo -e "\numask o=" >> /etc/skel/.bashrc
}

# Clean Getty
function configure_getty() {
    echo -e "\033[32m >>> Configuring: Gettys ... \033[0m"
    # Remove Unneeded Getty Instances
    sed -e 's/\(^[2-6].*getty.*\)/#\1/' -i /etc/inittab
}

# Disable BASH History
function disable_history() {
    echo -e "\033[32m >>> Configuring: BASH History ... \033[0m"
    # Disable System BASH History
    echo -e "\nunset HISTFILE" >> /etc/profile
}

# Simplify Logging
function simplified_log() {
    echo -e "\033[32m >>> Configuring: Simplified Logging ... \033[0m"
    if egrep -q "(CentOS release 5|CentOS Linux release 5)" /etc/redhat-release ; then
        # Stop Logging Daemon
        service syslog stop
        # Remove Log Files
        rm -rf /var/log/* /var/log/*/*
        rm -rf /var/log/news
        # Create New Log Files
        touch /var/log/{auth,daemon,cron,kernel,mail,messages}
        # Copy Simplified Logging Configuration
        cp -f settings/syslog /etc/syslog.conf
        # Copy Simplified Log Rotation Configuration
        cp -f settings/logrotate.syslog /etc/logrotate.d/syslog
        # Start Logging Daemon
        service syslog start
    elif egrep -q "(CentOS release 6|CentOS Linux release 6)" /etc/redhat-release ; then
        # Stop Logging Daemon
        service rsyslog stop
        # Remove Log Files
        rm -rf /var/log/* /var/log/*/*
        rm -rf /var/log/news
        # Create New Log Files
        touch /var/log/{auth,cron,daemon,kernel,mail,messages}
        # Copy Simplified Logging Configuration
        cp -f settings/rsyslog /etc/rsyslog.conf
        # Copy Simplified Log Rotation Configuration
        cp -f settings/logrotate.rsyslog /etc/logrotate.d/rsyslog
        # Start Logging Daemon
        service rsyslog start
    else
    echo -e "\033[31m Error: Unable to Simplified Logging. \033[0m"
        return 1
    fi
}

# Use PublicKey File Login & Disable Password
function use_sshkey() {
    echo -e "\033[32m >>> Configuring: Setting PublicKey File ... \033[0m"
    # Set SSH PublicKey File
    if [ "$PubKeyLink" != "http://www.sample.com/" ]; then
        rm -rf ~/.ssh
        mkdir -p ~/.ssh && chmod 700 ~/.ssh
        cd ~/.ssh && wget $PubKeyLink$PubKeyName
        chmod 600 ~/.ssh/$PubKeyName
        /sbin/restorecon -r ~/.ssh >/dev/null 2>&1
    else
    echo -e "\033[31m Error: You need to change PubKey's Name & Link to yours. \033[0m"
        return 1
    fi
    # Change sshd_config For PublicKey Authorization
    if [ -f ~/.ssh/$PubKeyName ]; then
        sed -i "s/^.*PermitEmptyPasswords .*/PermitEmptyPasswords no/g" /etc/ssh/sshd_config
        sed -i "s/^.*RSAAuthentication .*/RSAAuthentication yes/g" /etc/ssh/sshd_config
        sed -i "s/^.*PubkeyAuthentication .*/PubkeyAuthentication yes/g" /etc/ssh/sshd_config
        sed -i "s/^.*AuthorizedKeysFile/AuthorizedKeysFile/g" /etc/ssh/sshd_config
        sed -i "s/authorized_keys/$PubKeyName/g" /etc/ssh/sshd_config
        # Disable SSH Password Login For OpenSSH
        sed -i 's/^.*PermitRootLogin .*/PermitRootLogin without-password/g' /etc/ssh/sshd_config
        sed -i 's/^.*PasswordAuthentication .*/PasswordAuthentication no/g' /etc/ssh/sshd_config
    else
    echo -e "\033[31m Error: Unable to find PublicKey File. \033[0m"
        return 1
    fi
    # Clean sshd_config file
    # echo|cat /etc/ssh/sshd_config|awk '!a[$0]++' > /etc/ssh/sshd_config
    # Restart OpenSSH Daemon
    sshd_restart
}

# Set Time Zone
function configure_timezone() {
    echo -e "\033[32m >>> Configuring: Setting Time Zone ... \033[0m"
    # Configure Time Zone
    rm -rf /etc/localtime
    cp -f /usr/share/zoneinfo/Asia/Shanghai /etc/localtime
}

# Run Through Configuration Functions
function configure_basic() {
    # Configure Bashrc
    configure_bashrc

    # Remove Useless Gettys
    configure_getty

    # Logging Simplified
    simplified_log

    # BASH History Disabled
    disable_history

    # Ask If Default SSH Port 22 Should Be Changed
    if egrep -q "(^.*Port .*22.*)" /etc/ssh/sshd_config ; then
        echo -e "\033[31m Detected SSH Port: 22, It's Dangerous and Should Be Changed!!! \033[0m"
        change_sshport
    fi

    # Ask If Time Zone Should Be Set to Asia/Shanghai
    echo -n -e "\033[36m Do you wish to change timezone to Asia/Shanghai? \033[0m"
    read -t 60 -p "(Y/n): " OPTION_TZ
    # Check User Input
    if [ "$OPTION_TZ" != "n" ]; then
    # Execute Function
        configure_timezone
    fi

    # Ask If Use PublicKey Login & Disable Password
    echo -n -e "\033[36m Do you wish to use PublicKey login and disable password? \033[0m"
    read -t 60 -p "(y/N): " OPTION_KEY
    # Check User Input
    if [ "$OPTION_KEY" == "y" ]; then
    # Execute Function
        use_sshkey
    fi
}

# Create Package List & Set Kernel
function packages_create() {
    echo -e "\033[32m >>> Creating Package List ... \033[0m"
    # Determine OS Bit Type
    if [[ $(uname -m) == "i686" ]]; then
        echo -e "\033[35m Detected i686(x86)! \033[0m"
    elif [[ $(uname -m) == "x86_64" ]]; then
        echo -e "\033[35m Detected x86_64(x64)! \033[0m"
    else
    echo -e "\033[31m Error: Unable to determine OS Bit Type. \033[0m"
        exit 1
    fi
    # Detect CentOS 5.x
    if egrep -q "(CentOS release 5|CentOS Linux release 5)" /etc/redhat-release ; then
        echo -e "\033[35m Detected CentOS release 5.x! \033[0m"
        # Copy YUM CentOS-Base.repo Source
        rm -rf /etc/yum.repos.d/CentOS-Base.repo
        cp -f settings/CentOS5-Base.repo /etc/yum.repos.d/CentOS-Base.repo
        # Copy Base Package List
        cat packages/Base5|sort -uf|sed '/^$/d' > tmp/packages_minimal
        # Detect OpenVZ
        if [ -f /proc/user_beancounters ] || [ -d /proc/bc ]; then
            echo -e "\033[35m Detected OpenVZ! \033[0m"
            cat packages/Base5-OpenVZ|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Detect XEN PV, KVM or Physical Hardware/Hardware Virtualisation
        elif [[ $(uname -r) == *xen ]]; then
            echo -e "\033[35m Detected XEN PV! \033[0m"
        # Append Platform Relevent Packages To Package List
            cat packages/Base5-Xen|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Disable Kernel-xen Update
            sed -i '/^.*exclude=.*/d' /etc/yum.conf
            sed -i '/\[main\]/a\exclude=kernel-2.* kernel-xen-2.*' /etc/yum.conf
        # Detect KVM
        elif [[ $(uname -r) == *el5* ]]; then
            echo -e "\033[35m Detected KVM or Physical Hardware/Hardware Virtualisation! \033[0m"
        # Append Platform Relevent Packages To Package List
            cat packages/Base5-KVM|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Disable Kernel Update
            sed -i '/^.*exclude=.*/d' /etc/yum.conf
            sed -i '/\[main\]/a\exclude=kernel-2.* kernel-debug-2.* kernel-xen-2.* kernel-PAE-2.* kernel-doc-2.*' /etc/yum.conf
        fi
        # LNMP.ORG's Packages
        cat tmp/packages_minimal > tmp/lnmp_minimal
        cat packages/LNMP5 >> tmp/lnmp_minimal
        sort -uf -o tmp/lnmp_minimal tmp/lnmp_minimal
    # Detect CentOS 6.x
    elif egrep -q "(CentOS release 6|CentOS Linux release 6)" /etc/redhat-release ; then
        echo -e "\033[35m Detected CentOS release 6.x! \033[0m"
        # Copy YUM CentOS-Base.repo Source
        rm -rf /etc/yum.repos.d/*
        cp -f settings/CentOS6-Base.repo /etc/yum.repos.d/CentOS-Base.repo
        # Copy Base Package List
        cat packages/Base6|sort -uf|sed '/^$/d' > tmp/packages_minimal
        # Detect OpenVZ
        if [ -f /proc/user_beancounters ] || [ -d /proc/bc ]; then
            echo -e "\033[35m Detected OpenVZ! \033[0m"
            cat packages/Base6-OpenVZ|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Detect XEN PV, KVM or Physical Hardware/Hardware Virtualisation
        elif [ -d /proc/xen ] && [ -d /sys/bus/xen ]; then
            echo -e "\033[35m Detected XEN PV! \033[0m"
        # Append Platform Relevent Packages To Package List
            cat packages/Base6-Xen|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Disable Kernel-xen Update
            sed -i '/^.*exclude=.*/d' /etc/yum.conf
            sed -i '/\[main\]/a\exclude=kernel-2.* kernel-debug-2.* kernel-xen-2.* kernel-PAE-2.* kernel-doc-2.*' /etc/yum.conf
        # Detect KVM
        elif [[ $(uname -r) == *el6* ]]; then
            echo -e "\033[35m Detected KVM or Physical Hardware/Hardware Virtualisation! \033[0m"
        # Append Platform Relevent Packages To Package List
            cat packages/Base6-KVM|sort -uf|sed '/^$/d' >> tmp/packages_minimal
            sort -uf -o tmp/packages_minimal tmp/packages_minimal
        # Disable Kernel Update
            sed -i '/^.*exclude=.*/d' /etc/yum.conf
            sed -i '/\[main\]/a\exclude=kernel-2.* kernel-debug-2.* kernel-xen-2.* kernel-PAE-2.* kernel-doc-2.*' /etc/yum.conf
        fi
        # LNMP.ORG's Packages
        cat tmp/packages_minimal > tmp/lnmp_minimal
        cat packages/LNMP6 >> tmp/lnmp_minimal
        sort -uf -o tmp/lnmp_minimal tmp/lnmp_minimal
    else
        echo "\033[31m Error: Unable to Determine Distribution Type or Virtualization Type. \033[0m"
    exit 1
    fi
}

# YUM Remove Unneeded Packages
function lnmp_clean() {
    # List Original YUM Packages
    if [ -f tmp/lnmp_original ]; then
        cp -f tmp/lnmp_original tmp/lnmp_original.`date +"%Y-%m-%d_%H-%M-%S"`
    fi
    yum list installed|awk 'split($1,a,"."){if (NR>2){print a[1]}}'|sort -uf|sed '/^$/d' > tmp/lnmp_original
    cat tmp/lnmp_original|sed '/^[0-9]*$\|^[0-9]*:[0-9]*$\|^[0-9]*-[0-9]*$\|^@base\|^@updates\|^@anaconda-*\|^$/d'|sort -uf -o tmp/lnmp_original
    # YUM LNMP Install
    if [[ $(stat -c %s tmp/lnmp_original) != 0 ]] && [[ $(stat -c %s tmp/lnmp_minimal) != 0 ]]; then
        if egrep -q "(CentOS release 5|CentOS Linux release 5)" /etc/redhat-release ; then
            diff -abBi tmp/lnmp_original tmp/lnmp_minimal|grep '>'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/lnmp_installed
        elif egrep -q "(CentOS release 6|CentOS Linux release 6)" /etc/redhat-release ; then
            diff -abBi tmp/lnmp_original tmp/lnmp_minimal|grep '>'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/lnmp_installed
        else
        echo -e "\033[31m Error: Unable to Process lnmp_installed. \033[0m"
            exit 1
        fi
        if [[ $(stat -c %s tmp/lnmp_installed) != 0 ]]; then
            cat tmp/lnmp_installed|xargs yum -y install
        fi
    else
    echo "\033[31m Error: lnmp_original or lnmp_minimal is empty. \033[0m"
    exit 1
    fi
    # YUM Remove Packages
    if [[ $(stat -c %s tmp/lnmp_original) != 0 ]] && [[ $(stat -c %s tmp/lnmp_minimal) != 0 ]]; then
        diff -abBi tmp/lnmp_original tmp/lnmp_minimal|grep '<'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/lnmp_removed
        if [[ $(stat -c %s tmp/lnmp_removed) != 0 ]]; then
            cat tmp/lnmp_removed|xargs yum -y remove
        fi
    else
    echo "\033[31m Error: lnmp_original or lnmp_minimal is empty. \033[0m"
    exit 1
    fi
}
# Use YUM To Remove Packages
function packages_clean() {
    echo -e "\033[32m >>> Cleaning Packages ... \033[0m"
    # Detect LNMP
    if [ -f /root/lnmp ] || [ -f /root/vhost.sh ]; then
        # Ask If Want To Remove LNMP.ORG
        echo -n -e "\033[36m Do You Want To Remove LNMP? \033[0m"
        read -t 60 -p "(Y/n): " OPTION_LNMPR
        # Check User Input
        if [ "$OPTION_LNMPR" != "n" ]; then
            # Uninstall LNMP.ORG's Packages
            /etc/init.d/mysql stop
            /usr/local/php/sbin/php-fpm stop
            killall nginx mysqld php-cgi
            rm -rf /usr/local/php /usr/local/nginx /usr/local/mysql /usr/local/zend /etc/my.cnf /etc/init.d/mysql /root/vhost.sh /root/lnmp /root/run.sh
            chkconfig mysql off
            chkconfig nginx off
            chkconfig php-fpm off
        fi
    fi
    # List Original YUM Packages
    if [ -f tmp/packages_original ]; then
        cp -f tmp/packages_original tmp/packages_original.`date +"%Y-%m-%d_%H-%M-%S"`
    fi
    yum list installed|awk 'split($1,a,"."){if (NR>2){print a[1]}}'|sort -uf|sed '/^$/d' > tmp/packages_original
    cat tmp/packages_original|sed '/^[0-9]*$\|^[0-9]*:[0-9]*$\|^[0-9]*-[0-9]*$\|^@base\|^@updates\|^@anaconda-*\|^$/d'|sort -uf -o tmp/packages_original
    # YUM Packages Install
    if [[ $(stat -c %s tmp/packages_original) != 0 ]] && [[ $(stat -c %s tmp/packages_minimal) != 0 ]]; then
        if egrep -q "(CentOS release 5|CentOS Linux release 5)" /etc/redhat-release ; then
            diff -abBi tmp/packages_original tmp/packages_minimal|grep '>'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/packages_installed
        elif egrep -q "(CentOS release 6|CentOS Linux release 6)" /etc/redhat-release ; then
            diff -abBi tmp/packages_original tmp/packages_minimal|grep '>'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/packages_installed
        else
        echo -e "\033[31m Error: Unable to Process packages_installed. \033[0m"
            exit 1
        fi
        if [[ $(stat -c %s tmp/packages_installed) != 0 ]]; then
            cat tmp/packages_installed|xargs yum -y install
        fi
    else
    echo "\033[31m Error: Packages_original or Packages_minimal is empty. \033[0m"
    exit 1
    fi
    # YUM Remove Packages
    if [[ $(stat -c %s tmp/packages_original) != 0 ]] && [[ $(stat -c %s tmp/packages_minimal) != 0 ]]; then
        diff -abBi tmp/packages_original tmp/packages_minimal|grep '<'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/packages_removed
        if [[ $(stat -c %s tmp/packages_removed) != 0 ]]; then
            cat tmp/packages_removed|xargs yum -y remove
        fi
    else
    echo "\033[31m Error: Packages_original or Packages_minimal is empty. \033[0m"
    exit 1
    fi
}

# YUM Update Packages
function packages_update() {
    echo -e "\033[32m >>> YUM Update Packages ... \033[0m"
    # Update YUM Packages
    yum update -y
    # Upgrade Any Outdated Packages
    yum upgrade -y
}

# Purge YUM Package Cache
function packages_cache() {
    echo -e "\033[32m >>> Cleaning Package Cache ... \033[0m"
    # Delete all empty dir
    find / -depth -empty -type d -exec rmdir -v {} \ >/dev/null 2>&1
    # Clean Cached Packages
    yum clean all
    rm -rf /var/cache/yum/*
}

# Execute Install Functions
function packages_minimal() {
    packages_create
    packages_clean
    packages_update
    packages_clean
    packages_cache
}

# Install OpenSSH & Sets Configuration
function configure_ssh() {
    echo -e "\033[32m >>> Configuring SSH ... \033[0m"
    # Install OpenSSH
    yum install -y openssh openssh-server openssh-client
    # Copy SSH Configuration Files
    cp -f /etc/ssh/sshd_config /etc/ssh/sshd_config.bak
    cp -f settings/sshd_config /etc/ssh/sshd_config
    cp -f settings/ssh_config /etc/ssh/ssh_config
    # Restart OpenSSH Daemon
    sshd_restart
}

# Restart OpenSSH Daemon
function sshd_restart() {
    if [ -f /etc/rc.d/init.d/sshd ]; then
        /etc/rc.d/init.d/sshd restart
    else
        chkconfig sshd on
        service sshd restart
    fi
}

# Stop Unnessery Services
function configure_service() {
    echo -e "\033[32m >>> Configuring Services ... \033[0m"
    # List All Startup Services
    if [ -f tmp/services_original ]; then
        cp -f tmp/services_original tmp/services_original.`date +"%Y-%m-%d_%H-%M-%S"`
    fi
    /sbin/chkconfig --list|grep "3:on"|awk '{print $1}' > tmp/services_original
    # Remove Necessary Services From List
    cat settings/Services_needed|sort -uf|sed '/^$/d' > tmp/services_run
    if [[ $(stat -c %s tmp/services_run) != 0 ]]; then
        diff -abBi tmp/services_original tmp/services_run|grep '<'|awk '{print$2}'|sort -uf|sed '/^$/d' > tmp/services_stop
        # Stop Unnessery Services
        if [[ $(stat -c %s tmp/services_stop) != 0 ]]; then
            for service in `cat tmp/services_stop`
            do
                chkconfig $service off
                service $service stop
            done
        fi
    else
    echo "\033[31m Error: services_run is empty. \033[0m"
    return 1
    fi

}

# Change Default SSH Port
function change_sshport() {
    echo -e "\033[32m >>> Configuring: Changing SSH Port ... \033[0m"
    # Take User Input
    echo -n -e "\033[36m Enter New SSH Port \033[0m"
    read -t 60 -p "(Default: 22): " SSHPORT
    if [ "$SSHPORT" = "" ] ; then
    SSHPORT="22"
    fi
    # Change Default SSH Port in OpenSSH
    sed -i "s/^.*Port .*/Port $SSHPORT/g" /etc/ssh/sshd_config
    # Add iptables SSH Port Rule
    if [ -f /sbin/iptables ]; then
        service iptables restart
        iptables -A INPUT -m state --state NEW -m tcp -p tcp --dport $SSHPORT -j ACCEPT
        iptables-save > /etc/sysconfig/iptables
    fi
    # Restart OpenSSH Daemon
    sshd_restart
}

# Install Extra Packages Defined In List
function install_extra() {
    # Install Extra Packages
    cat packages/Extra|sort -uf|sed '/^$/d' > tmp/packages_extra
    if [[ $(stat -c %s tmp/packages_extra) != 0 ]]; then
        cat tmp/packages_extra|xargs yum -y install
    fi
}

# Add New User Account
function add_user() {
    echo -e "\033[32m >>> Configuring: Add New User Account ... \033[0m"
    # Take User Input
    echo -n -e "\033[36m Please Enter a UserName: \033[0m"
    read -e USERNAME
    # Add User Based On Input
    useradd -m -s /bin/bash $USERNAME
    # Set Password For Newly Added User
    passwd $USERNAME
    # Allow New User SSH Login
    echo 'AllowUsers $USERNAME' >> /etc/ssh/sshd_config
    sshd_restart
}

# Disable Root Login
function disable_root() {
    echo -e "\033[32m >>> Configuring: Disabling Root SSH Login ... \033[0m"
    # Disable Root SSH Login For OpenSSH
    sed -i 's/^.*PermitRootLogin .*/PermitRootLogin no/g' /etc/ssh/sshd_config
    sshd_restart
}

# Ask If Root SSH Should Be Disabled & Add New User Account
function configure_root() {
    echo -e "\033[32m >>> Ask If Root SSH Should Be Disabled ... \033[0m"
    echo -n -e "\033[36m Do you wish to disable root SSH logins? Keep enabled if you don't plan on making any users! (Y/n): \033[0m"
    read -t 60 -e OPTION_ROOT
    # Check User Input
    if [ "$OPTION_ROOT" != "n" ]; then
    # Execute Function
        add_user
        disable_root
    fi
}

#################
## Init Script ##
#################

case "$1" in
    # Minimise System & Install OpenSSH
    ssh)
        minimal_prepare
        configure_ssh
        packages_minimal
        change_sshport
        configure_service
    ;;
    # Configure Install
    configure)
        minimal_prepare
        configure_basic
    ;;
    # Purge YUM Package Cache
    clean)
        minimal_prepare
        configure_service
        packages_cache
    ;;
    # Change SSH Port
    sshport)
        change_sshport
    ;;
    # Install Extra Packages
    extra)
        minimal_prepare
        install_extra
        configure_service
        packages_cache
    ;;
    # Disable Root Login And Add New User Account
    disroot)
        configure_root
    ;;
    # Show Help
    *)
    echo -e "\033[32m >>> You must run this script with options. They are outlined below: \033[0m"
    echo -e "\033[33m For a minimal OpenSSH based install: bash CentOS_Minimal.sh ssh \033[0m"
    echo -e "\033[33m To set the clock, clean files and logging: bash CentOS_Minimal.sh configure \033[0m"
    echo -e "\033[33m To change default SSH port: bash CentOS_Minimal.sh change_sshport \033[0m"
    echo -e "\033[33m To install extra packages: bash CentOS_Minimal.sh extra \033[0m"
    echo -e "\033[33m To purge yum packages cache : bash CentOS_Minimal.sh clean \033[0m"
    echo -e "\033[33m To disable root login and add new user : bash CentOS_Minimal.sh disroot \033[0m"
    ;;
esac
